pygeodesy.rhumb

Package pygeodesy :: Package rhumb |
[frames] | no frames]

# Package rhumb

Package of lazily imported `rhumb` modules rhumb.aux_, rhumb.ekx and rhumb.solve.

Note: `S12` area calculations in classes RhumbAux and RhumbLineAux depend on class AuxDST which requires numpy to be installed, version 1.16 or newer.

Version: 25.12.06

Submodules
pygeodesy.rhumb.aux_: A pure Python version of Karney's Auxiliary Latitudes, C++ classes Rhumb and RhumbLine from GeographicLib version 2.2+ renamed to RhumbAux respectively RhumbLineAux. pygeodesy.rhumb.bases: (INTERNAL) base classes `RhumbBase` and `RhumbLineBase`, pure Python version of Karney's C++ classes Rhumb and RhumbLine from GeographicLib versions 2.0 and 2.2 and Karney's C++ example Rhumb intersect. pygeodesy.rhumb.ekx: A pure Python version of Karney's elliptic functions, Krüger series expansion, C++ classes Rhumb and and RhumbLine from GeographicLib version 2.0, kept for backward compatibility. pygeodesy.rhumb.solve: Wrapper to invoke Karney's RhumbSolve utility as an (exact) rhumb or rhumb line from either GeographicLib 2.0 or 2.2+.

Classes
| RhumbAux Class to solve the direct and inverse rhumb problems, based on Auxiliary Latitudes for accuracy near the poles.
| RhumbLineAux Compute one or several points on a single rhumb line.
| Rhumb Class to solve the direct and inverse rhumb problems, based on elliptic functions or Krüger series expansion
| RhumbLine Compute one or several points on a single rhumb line.
| RhumbSolve Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.Rhumb and pygeodesy.RhumbAux.
| RhumbLineSolve Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.RhumbLine and pygeodesy.RhumbLineAux.
| RhumbSolve7Tuple 7-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12` and the area `S12` under the rhumb line between both points.
| Rhumb8Tuple 8-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12, a12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12`, the area `S12` under the rhumb line and the angular distance `a12` between both points.

Variables
| __all__ = `_ALL_LAZY.rhumb`
| __getattr__ = `_lazy_import_as(__name__)`